==> core-react-0.8.0.tgz: package/es/dialog/DialogHeader.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import cx from 'classnames';
import PropTypes from 'prop-types';
import React from 'react';
import Icon from '../Icon';
import { typeMap } from './config';

var DialogHeader = function DialogHeader(props, context) {
  var _typeMap$type;

  var className = props.className,
      icon = props.icon,
      type = props.type,
      other = _objectWithoutProperties(props, ["className", "icon", "type"]);

  var iconType = icon || ((_typeMap$type = typeMap[type]) === null || _typeMap$type === void 0 ? void 0 : _typeMap$type.icon);
  return React.createElement("div", _extends({
    className: cx("".concat("waui", "-dialog__main-header"), className)
  }, other), React.createElement(Icon, {
    type: iconType,
    className: cx("".concat("waui", "-dialog__main-header-icon"), "".concat("waui", "-dialog__main-header-icon_").concat(type))
  }));
};

DialogHeader.propTypes = {
  className: PropTypes.string,
  icon: PropTypes.string,
  type: PropTypes.oneOf(['confirm', 'accept', 'warning', 'danger', 'success', 'info', 'error'])
};
DialogHeader.defaultProps = {
  type: 'confirm'
};
export default DialogHeader;

==> core-react-0.8.2.tgz: package/es/dialog/DialogHeader.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import cx from 'classnames';
import PropTypes from 'prop-types';
import React from 'react';
import Icon from '../Icon';
import { typeMap } from './config';

var DialogHeader = function DialogHeader(props, context) {
  var _typeMap$type;

  var className = props.className,
      icon = props.icon,
      type = props.type,
      other = _objectWithoutProperties(props, ["className", "icon", "type"]);

  var iconType = icon || ((_typeMap$type = typeMap[type]) === null || _typeMap$type === void 0 ? void 0 : _typeMap$type.icon);
  return (/*#__PURE__*/React.createElement("div", _extends({
      className: cx("".concat("waui", "-dialog__main-header"), className)
    }, other), /*#__PURE__*/React.createElement(Icon, {
      type: iconType,
      className: cx("".concat("waui", "-dialog__main-header-icon"), "".concat("waui", "-dialog__main-header-icon_").concat(type))
    }))
  );
};

DialogHeader.propTypes = {
  className: PropTypes.string,
  icon: PropTypes.string,
  type: PropTypes.oneOf(['confirm', 'accept', 'warning', 'danger', 'success', 'info', 'error'])
};
DialogHeader.defaultProps = {
  type: 'confirm'
};
export default DialogHeader;
